pypaginate.adapters
===================

.. py:module:: pypaginate.adapters

.. autoapi-nested-parse::

   Adapters — thin backend implementations.



Submodules
----------

.. toctree::
   :maxdepth: 1

   /api/pypaginate/adapters/fastapi/index
   /api/pypaginate/adapters/memory/index
   /api/pypaginate/adapters/sqlalchemy/index


